@@ -10,7 +10,7 @@ use HTML::Parser;
 use HTML::Form;
 use Digest::MD5();
 
-our $VERSION = '8.01';
+our $VERSION = '8.02';
 
 # $Id: $
 # $Log: LaPoste.pm,v $
@@ -163,12 +163,17 @@ sub _rel_url {
 	$base =~ m!([^/]*//[^/]*)! && "$1$rel";
     } else {
 	$base =~ s/\?.*//;
-	my $s = "$base/../$rel";
-	while ($s =~ s![^/]*/\.\./!!) {}
-	$s;
+	_rel_fullurl("$base/../$rel");
     }
 }
 
+sub _rel_fullurl {
+    my ($s) = @_;
+    while ($s =~ s![^/]*/\.\./!!) {}
+    $s;
+}
+
+
 sub _output { my $f = shift; open(my $F, ">$f") or die "output in file $f failed: $!\n"; print $F $_ foreach @_; 1 }
 
 # to update %img_md5sum_to_number, set $debug_imgs to 1, 
@@ -318,6 +323,14 @@ sub new {
 
     $self->{ua} ||= LWP::UserAgent->new(agent => 'Mozilla');
 
+    $self->{ua}->add_handler(request_preprepare => sub {
+        my ($request, $ua, $h) = @_;
+        if ($request->uri =~ m!/\.\./!) {
+            $request->uri(_rel_fullurl($request->uri));
+        }
+        #print $request->uri . "\n";
+    });
+
     _login($self);
     $self;
 }
